@@ -5,7 +5,6 @@
 #' @param p0  The cut-off P-value.
 #' @param nu The order statistic of Gaussian covariates used for comparison.
 #' @param km The maximum number of included covariates at each stage irrespective of cut-off P-value.
-#' @param kmx The maximum number of included covariates at each stage for the given  cut-off P-value.
 #' @param mx  The maximum number covariates for an all subset search.
 #' @param kx The excluded covariates.
 #' @param lm  The maximum number of linear approximations. 
@@ -17,7 +16,7 @@
 #' data(boston)
 #' bostint<-fgeninter(boston[,1:13],2)[[1]]
 #' a<-f2st(boston[,14],bostint,lm=3,sub=T)
-f2st<-function(y,x,p0=0.01,nu=1,km=0,kmx=0,mx=21,kx=0,lm=9^9,sub=F,inr=T,xinr=F){
+f2st<-function(y,x,p0=0.01,nu=1,km=0,mx=21,kx=0,lm=9^9,sub=F,inr=T,xinr=F){
 	kxx<-kx
 	n<-length(y)
 	qq<-length(x[1,])
@@ -26,7 +25,7 @@ f2st<-function(y,x,p0=0.01,nu=1,km=0,kmx=0,mx=21,kx=0,lm=9^9,sub=F,inr=T,xinr=F)
 	mn<-0
 	pvv<- matrix(c(0,0,0,0,0),nrow=1)
 	while(kv>0.5){
-		tmp<-f1st(y,x,p0=p0,nu=nu,km=km,kmx=kmx,mx=mx,kx=kxx,sub=sub,inr=inr,xinr=xinr)[[1]]
+		tmp<-f1st(y,x,p0=p0,nu=nu,km=km,mx=mx,kx=kxx,sub=sub,inr=inr,xinr=xinr)[[1]]
 #		print(tmp)
 #		readline("tmp")
 		if(tmp[1,1]<=0){kv<-0}
