@@ -4,13 +4,14 @@
 #' @param x  The covariates.
 #' @param ind The indices of the subset whose P-values are required.
 #' @param q   The total  number of covariates from which ind was selected.
+#' @param nu The order statistic used to compute the P-values.
 #' @param inr Logical If TRUE intercept to be included
 #' @param xinr Logical If TRUE intercept already included, overides inr
 #' @return apv In order the subset ind, the regression coefficients, the Gaussian P-values, the standard P-values.
 #' @return res The residuals.
 #' @examples 
-#' a<-fpval(boston[,14],boston[,1:13],c(1,2,4:6,8:13),13)
-fpval<-function(y,x,ind,q=-1,inr=T,xinr=F){
+#' a<-fpval(boston[,14],boston[,1:13],c(1,2,4:6,8:13),q=13)
+fpval<-function(y,x,ind,q=-1,nu=1,inr=T,xinr=F){
    	n<-length(y)
    	kx<-length(x)/n
    	if(xinr){inr<-F}
@@ -25,16 +26,17 @@ fpval<-function(y,x,ind,q=-1,inr=T,xinr=F){
 		if(xinr){q<-kx-1}
 	}
     	ki<-length(ind)
+	q<-q-ki
     	apv<-double(2*ki)
     	dim(apv)<-c(ki,2)
     	b<-lm(y~0+x[,ind])
     	res<-as.double(b$res)
     	apv[,2]<-as.double(summary(b)[[4]][1:ki,4])
-    	apv[1:ki,1]<-pbeta(apv[1:ki,2],1,q+1)
+    	apv[1:ki,1]<-pbeta(apv[1:ki,2],nu,q+2-nu)
     	if(xinr){apv[ki,1]<-apv[ki,2]
         		ind[ki]<-0
     	}
-   	 beta<-matrix(b$coef,ncol=1)
+	beta<-matrix(b$coef,ncol=1)
     	apv<-cbind(ind,beta,apv)
     	list(apv,res)
 }
